<?php
/**
 * Omnisend Cart Event Class
 *
 * @package OmnisendPlugin
 */

defined( 'ABSPATH' ) || exit;

class Omnisend_Cart_Event {

	const ADDED_PRODUCT_TO_CART = 'added product to cart';
	const STARTED_CHECKOUT      = 'started checkout';

	public static function added_product_to_cart() {
		if ( is_omnisend_cart_rebuild_url() ) {
			return;
		}

		if ( self::is_cart_valid() ) {
			Omnisend_Event_Tracker::track_event( self::ADDED_PRODUCT_TO_CART, '', self::build_event_props() );
		}
	}

	public static function started_checkout( $email = '' ) {
		if ( self::is_cart_valid() ) {
			Omnisend_Event_Tracker::track_event( self::STARTED_CHECKOUT, $email, self::build_event_props() );
		}
	}

	private static function is_cart_valid() {
		return ! WC()->cart->is_empty();
	}

	private static function build_event_props() {
		$items = array();

		$cart = WC()->cart;

		foreach ( $cart->get_cart() as $cart_item_key => $cart_item ) {
			$data      = $cart_item['data'];
			$line_item = array(
				'product_id'   => $cart_item['product_id'],
				'variation_id' => $cart_item['variation_id'],
				'quantity'     => $cart_item['quantity'],
				'link'         => $data->get_permalink( $cart_item ),
				'attributes'   => $cart_item['variation'],
			);
			array_push( $items, $line_item );
		}

		$cart->calculate_totals();

		return array(
			'raw'          => array(
				'currency'        => get_woocommerce_currency(),
				'currency_symbol' => get_woocommerce_currency_symbol(),
				'items'           => $items,
				'applied_coupons' => $cart->get_applied_coupons(),
				'totals'          => $cart->get_totals(),
			),
			'item_count'   => $cart->get_cart_contents_count(),
			'checkout_url' => self::build_checkout_url( $cart ),
		);
	}

	private static function build_checkout_url( $cart ) {
		$products = array();

		foreach ( $cart->get_cart() as $cart_item_key => $cart_item ) {
			$product = array(
				'product_id'   => $cart_item['product_id'],
				'quantity'     => $cart_item['quantity'],
				'variation_id' => $cart_item['variation_id'],
				'variation'    => $cart_item['variation'],
			);

			array_push( $products, $product );
		}

		$cart_to_recover = array( 'products' => $products );
		$base64_encoded  = base64_encode( json_encode( $cart_to_recover ) );

		return home_url( '?action=rebuildCart&omniCart=' . $base64_encoded );
	}
}
