<?php
/**
 * Omnisend Plugin Event Class
 *
 * @package OmnisendPlugin
 */

defined( 'ABSPATH' ) || exit;

class Omnisend_Plugin_Event {

	const PLUGIN_ACTIVATION_SUCCEEDED                  = 'pluginActivationSucceeded';
	const PLUGIN_ACTIVATION_FAILED                     = 'pluginActivationFailed';
	const API_KEY_SAVING_SUCCEEDED                     = 'apiKeySavingSucceeded';
	const API_KEY_SAVING_FAILED                        = 'apiKeySavingFailed';
	const CONNECT_ACCOUNT_CLICKED                      = 'connectAccountClicked';
	const CREATE_ACCOUNT_CLICKED                       = 'createAccountClicked';
	const GET_STARTED_CLICKED                          = 'getStartedClicked';
	const PERMALINKS_NOTICE_SHOWN                      = 'permalinksNoticeShown';
	const PERMALINKS_NOTICE_CLICKED                    = 'permalinksNoticeClicked';
	const CONNECTION_ERROR_NOTICE_SHOWN                = 'connectionErrorNoticeShown';
	const CONNECTION_ERROR_NOTICE_SWITCH_BRAND_CLICKED = 'connectionErrorNoticeSwitchBrandClicked';
	const WOOCOMMERCE_OAUTH_DENY_BUTTON_CLICKED        = 'woocommerceOauthDenyButtonClicked';
	const WOOCOMMERCE_OAUTH_SUCCESS                    = 'woocommerceOauthSuccess';
	const PLUGIN_UPDATED                               = 'pluginUpdated';
	const UPDATE_PERMISSIONS_OMNISEND_NOTICE_SHOWN     = 'updatePermissionsOmnisendNoticeShown';
	const UPDATE_PERMISSIONS_OMNISEND_NOTICE_CLICKED   = 'updatePermissionsOmnisendNoticeClicked';
	const UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_SHOWN     = 'updatePermissionsWpAdminNoticeShown';
	const UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_CLICKED   = 'updatePermissionsWpAdminNoticeClicked';
	const SYNC_SETTINGS_SECTION_SHOWN                  = 'syncSettingsSectionShown';

	public static function plugin_activated() {
		Omnisend_Tracker::track_plugin_event(
			self::PLUGIN_ACTIVATION_SUCCEEDED,
			array(
				'isMultisiteEnabled' => is_multisite(),
			)
		);
	}

	public static function failed_plugin_activation( $reason = '' ) {
		Omnisend_Tracker::track_plugin_event(
			self::PLUGIN_ACTIVATION_FAILED,
			array(
				'reason'             => $reason,
				'isMultisiteEnabled' => is_multisite(),
			)
		);
	}

	public static function plugin_updated() {
		Omnisend_Tracker::track_plugin_event( self::PLUGIN_UPDATED );
	}

	public static function api_key_saved() {
		Omnisend_Tracker::track_plugin_event( self::API_KEY_SAVING_SUCCEEDED );
	}

	public static function connection_event( $event_name = '', $reason = '' ) {
		switch ( $event_name ) {
			case self::CONNECT_ACCOUNT_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::CONNECT_ACCOUNT_CLICKED );
				break;
			case self::CREATE_ACCOUNT_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::CREATE_ACCOUNT_CLICKED );
				break;
			case self::GET_STARTED_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::GET_STARTED_CLICKED );
				break;
			case self::PERMALINKS_NOTICE_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::PERMALINKS_NOTICE_CLICKED );
				break;
			case self::CONNECTION_ERROR_NOTICE_SHOWN:
				Omnisend_Tracker::track_plugin_event(
					self::CONNECTION_ERROR_NOTICE_SHOWN,
					array(
						'reason' => $reason,
					)
				);
				break;
			case self::CONNECTION_ERROR_NOTICE_SWITCH_BRAND_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::CONNECTION_ERROR_NOTICE_SWITCH_BRAND_CLICKED );
				break;
			case self::WOOCOMMERCE_OAUTH_DENY_BUTTON_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::WOOCOMMERCE_OAUTH_DENY_BUTTON_CLICKED );
				break;
			case self::WOOCOMMERCE_OAUTH_SUCCESS:
				Omnisend_Tracker::track_plugin_event( self::WOOCOMMERCE_OAUTH_SUCCESS );
				break;
			case self::UPDATE_PERMISSIONS_OMNISEND_NOTICE_SHOWN:
				Omnisend_Tracker::track_plugin_event( self::UPDATE_PERMISSIONS_OMNISEND_NOTICE_SHOWN );
				break;
			case self::UPDATE_PERMISSIONS_OMNISEND_NOTICE_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::UPDATE_PERMISSIONS_OMNISEND_NOTICE_CLICKED );
				break;
			case self::UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_SHOWN:
				Omnisend_Tracker::track_plugin_event( self::UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_SHOWN );
				break;
			case self::UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_CLICKED:
				Omnisend_Tracker::track_plugin_event( self::UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_CLICKED );
				break;
		}
	}

	public static function permalinks_notice_shown() {
		Omnisend_Tracker::track_plugin_event( self::PERMALINKS_NOTICE_SHOWN );
	}

	public static function sync_settings_shown() {
		Omnisend_Tracker::track_plugin_event( self::SYNC_SETTINGS_SECTION_SHOWN );
	}
}
