<?php
/**
 * Omnisend Cart Restore Functions
 *
 * @package OmnisendPlugin
 */

defined( 'ABSPATH' ) || exit;

function omnisend_restore_cart() {
	// phpcs:disable WordPress.Security.NonceVerification
	global $woocommerce;

	if ( ! empty( $_GET['cartID'] ) ) {

		$cart_id     = sanitize_key( $_GET['cartID'] );
		$link        = OMNISEND_API_URL . 'carts/' . $cart_id;
		$curl_result = Omnisend_Helper::omnisend_api( $link, 'GET' );

		if ( $curl_result['code'] === 200 ) {
			Omnisend_Logger::log( 'info', 'carts', $link, 'Cart with ID ' . $cart_id . ' was succesfully restored!' );
			$resp_data = json_decode( $curl_result['response'] );
			if ( null !== WC()->session ) {
				WC()->session->set( 'omnisend_cartID', $resp_data->cart_id );
				WC()->session->set( 'omnisend_cart_synced', 1 );
			}
			if ( sizeof( $resp_data->products ) > 0 ) {
				// Clean the cart before restoring it.
				$woocommerce->cart->empty_cart();
			}

			foreach ( $resp_data->products as $product ) {
				// phpcs:disable WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
				if ( $product->variantID !== $product->productID ) {
					$woocommerce->cart->add_to_cart( $product->productID, $product->quantity, $product->variantID );
				} else {
					$woocommerce->cart->add_to_cart( $product->productID, $product->quantity );
				}
				// phpcs:enable
			}
			// Set restored cartID to the current cart.
			$user_id = get_current_user_id();
			if ( $user_id > 0 ) {
				// phpcs:ignore WordPress.NamingConventions.ValidVariableName.UsedPropertyNotSnakeCase
				update_user_meta( $user_id, 'omnisend_cartID', $resp_data->cartID );
			}

			$redirect_url = wc_get_cart_url();

			if ( ! empty( $_SERVER['QUERY_STRING'] ) ) {
				$redirect_url = add_query_arg( wp_unslash( $_SERVER['QUERY_STRING'] ), '', $redirect_url ); // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
			}

			$redirect_url = remove_query_arg( array( 'action' ), $redirect_url );
			wp_redirect( esc_url_raw( $redirect_url ) );

			exit;
		}
	}
	wp_redirect( '/' );
	exit;
	// phpcs:enable
}
