<?php
/**
 * Plugin Name: Omnisend for Woocommerce
 * Plugin URI: https://www.omnisend.com
 * Description: This plugin connects your Woocommerce site with your Omnisend account.
 * Version: 1.12.2
 * Author: Omnisend
 * Author URI: https://www.omnisend.com
 * Developer: Omnisend
 * Developer URI: https://developers.omnisend.com
 *
 * WC requires at least: 2.2
 * WC tested up to: 7.1
 *
 * Copyright: © 2018 Omnisend
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package OmnisendPlugin
 */

defined( 'ABSPATH' ) || exit;

define( 'OMNISEND_APP_URL', 'https://app.omnisend.com' );
define( 'OMNISEND_API_URL', 'https://api.omnisend.com/v3/' );
define( 'OMNISEND_SNIPPET_URL', 'https://omnisnippet1.com/inshop/launcher-v2.js' );
define( 'OMNISEND_DISCOUNTS_KB_ARTICLE_URL', 'https://support.omnisend.com/en/articles/5846981-discount-content-block-for-woocommerce' );
define( 'OMNISEND_CALLBACK_URL', OMNISEND_APP_URL . '/REST/woocommerce/keys' );
define( 'OMNISEND_TRACKING_KEY', 'qhyXzQsK7hnynKH0C6qVyVqCJWvWt8atAHB' );
define( 'OMNISEND_TRACKING_URL', OMNISEND_APP_URL . '/REST/woocommerce/track' );
define( 'OMNISEND_LOGS_URL', OMNISEND_APP_URL . '/woocommerce/plugin/logs' );
define( 'OMNISEND_ACTIVATION_URL', OMNISEND_APP_URL . '/woocommerce/plugin/activation' );
define( 'OMNISEND_UPDATE_URL', OMNISEND_APP_URL . '/woocommerce/plugin/update' );
define( 'OMNISEND_SETTINGS_PAGE', 'omnisend-woocommerce' );
define( 'OMNISEND_LOGS_PAGE', 'omnisend-logs' );
define( 'OMNISEND_SYNC_PAGE', 'omnisend-sync' );
define( 'OMNISEND_WC_API_APP_NAME', 'Omnisend App' );
define( 'OMNISEND_API_KEY_HEADER_NAME', 'X-API-KEY' );
define( 'OMNISEND_ORIGIN_HEADER_NAME', 'X-Omnisend-Origin' );
define( 'OMNISEND_ORIGIN_HEADER_VALUE', 'woocommerce' );
define( 'OMNISEND_LOGIN_URL', OMNISEND_APP_URL . '/login' );
define( 'OMNISEND_REGISTRATION_URL', OMNISEND_APP_URL . '/registrationv2/email' );
define( 'OMNISEND_PLUGIN_INSTALL_URL', 'REST/woocommerce/install' );
define( 'OMNISEND_ONBOARDING_URL', OMNISEND_APP_URL . '/dashboard' );
define( 'OMNISEND_SWITCH_BRANDS_URL', OMNISEND_APP_URL . '/accounts/switch-store' );
define( 'OMNISEND_EVENTS_TRACKING_URL', OMNISEND_APP_URL . '/woocommerce/events/track' );

require_once 'manager/class-omnisend-logger.php';
require_once 'manager/class-omnisend-manager-assistant.php';
require_once 'manager/class-omnisend-helper.php';
require_once 'manager/class-omnisend-manager.php';
require_once 'manager/class-omnisend-sync-manager.php';
require_once 'manager/class-omnisend-server-session.php';
require_once 'manager/class-omnisend-user-storage.php';
require_once 'manager/class-omnisend-contact-resolver.php';
require_once 'manager/class-omnisend-tracker.php';
require_once 'manager/class-omnisend-event-tracker.php';
require_once 'manager/class-omnisend-logs-sender.php';
/*Include Model classes*/
require_once 'model/class-omnisend-product.php';
require_once 'model/class-omnisend-contact.php';
require_once 'model/class-omnisend-cart.php';
require_once 'model/class-omnisend-order.php';
require_once 'model/class-omnisend-category.php';
require_once 'model/class-omnisend-sync.php';
require_once 'model/class-omnisend-plugin-event.php';
require_once 'model/class-omnisend-connection-error.php';
require_once 'model/class-omnisend-cart-event.php';
/*Include Ajax functions*/
require_once 'class-omnisend-ajax.php';
/*Include settings page display function*/
require_once 'omnisend-settings-page.php';
/*Include logs page display function*/
require_once 'omnisend-logs.php';
/*Include Woocommerce hooks*/
require_once 'omnisend-woocommerce-hooks.php';
/*Include Woocommerce hooks*/
require_once 'omnisend-rebuild-cart.php';
require_once 'omnisend-restore-cart.php';
/* Include repository */
require_once 'class-omnisend-sync-stats-repository.php';
/* Include views */
require_once 'view/settings/api-access-notice.php';
require_once 'view/settings/connected.php';
require_once 'view/settings/connection.php';
require_once 'view/settings/permalink-notice.php';
require_once 'view/settings/connection-error-notice.php';
require_once 'view/settings/tag.php';
require_once 'view/settings/sync.php';
require_once 'view/settings/checkout-opt-in-checkbox.php';

require_once 'includes/omnisend-api.php';
require_once 'includes/class-omnisend-install.php';
require_once 'includes/class-omnisend-logs.php';


$omnisend_plugin_version = Omnisend_Helper::omnisend_plugin_version();

/*Declare plugin's settings page*/
add_action( 'admin_menu', 'omnisend_woocommerce_menu' );

function omnisend_woocommerce_menu() {
	$page_title = 'Omnisend for Woocommerce';
	$menu_title = 'Omnisend';
	$capability = 'manage_options';
	$menu_slug  = OMNISEND_SETTINGS_PAGE;
	$function   = 'omnisend_show_settings_page';
	$icon_url   = plugin_dir_url( __FILE__ ) . 'assets/img/omnisend-icon.png';

	$position = 2;

	add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );
	add_submenu_page( $menu_slug, __( 'General' ), __( 'General' ), $capability, $menu_slug, $function );
	add_submenu_page( $menu_slug, __( 'Logs' ), __( 'Logs' ), $capability, OMNISEND_LOGS_PAGE, 'omnisend_show_logs' );
	if ( get_option( 'omnisend_api_key', null ) !== null ) {
		add_submenu_page(
			$menu_slug,
			__( 'Sync' ),
			__( 'Sync' ),
			$capability,
			OMNISEND_SYNC_PAGE,
			'omnisend_show_sync'
		);
	}
}

/*Include scripts and styles for settings page and get started notice*/
add_action( 'admin_enqueue_scripts', 'omnisend_admin_scripts_and_styles' );
function omnisend_admin_scripts_and_styles() {
	wp_enqueue_script(
		'omnisend-wp-admin-script.js',
		plugin_dir_url( __FILE__ ) . 'assets/js/omnisend-wp-admin-script.js?' . time(),
		array(),
		'1.0.0',
		true
	);

	// phpcs:disable WordPress.Security.NonceVerification
	if ( isset( $_GET['page'] ) ) {
		if ( in_array( $_GET['page'], array( OMNISEND_SETTINGS_PAGE, OMNISEND_LOGS_PAGE, OMNISEND_SYNC_PAGE ), true ) ) {
			wp_enqueue_script(
				'omnisend-settings-script.js',
				plugin_dir_url( __FILE__ ) . 'assets/js/omnisend-settings-script.js?' . time(),
				array(),
				'1.0.0',
				true
			);
			wp_enqueue_style(
				'omnisend-admin-style.css',
				plugin_dir_url( __FILE__ ) . 'assets/css/omnisend-admin-style.css?' . time()
			);
			wp_enqueue_style( 'roboto.css', plugin_dir_url( __FILE__ ) . 'assets/fonts/roboto/roboto.css?' . time() );
		}
	}
	// phpcs:enable
}

/*Include front scripts */
add_action( 'wp_enqueue_scripts', 'omnisend_front_scripts_and_styles' );
function omnisend_front_scripts_and_styles() {
	$handle = 'omnisend-front-script.js';
	$file   = plugin_dir_url( __FILE__ ) . 'assets/js/omnisend-front-script.js?' . time();

	wp_register_script( $handle, $file, array(), '1.0.0', true );
	wp_localize_script(
		$handle,
		'omnisend_woo_data',
		array(
			'ajax_url'   => admin_url( 'admin-ajax.php' ),
			'contact_id' => Omnisend_User_Storage::get_contact_id(),
		)
	);
	wp_enqueue_script( $handle, $file, array(), '1.0.0', true );
}

/*After plugin activation - go to settings page*/
add_action( 'activated_plugin', 'omnisend_activation' );
function omnisend_activation( $plugin ) {
	Omnisend_Logger::hook();
	if ( $plugin == plugin_basename( __FILE__ ) ) {
		omnisend_activated();
	}
}

/**
 * Define Omnisend cron schedules.
 *
 * @param array $schedules List of WP scheduled cron jobs.
 *
 * @return array
 */
function omnisend_cron_schedules( $schedules ) {
	$schedules['omnisend_every_two_minutes'] = array(
		'interval' => 60 * 2,
		'display'  => __( 'Every 2 minutes', 'omnisend-woocommerce' ),
	);

	$schedules['omnisend_every_five_minutes'] = array(
		'interval' => 60 * 5,
		'display'  => __( 'Every 5 minutes', 'omnisend-woocommerce' ),
	);

	return $schedules;
}

/**
 * Init Omnisend crons.
 *
 * @return void
 */
function omnisend_init_crons() {
	// phpcs:ignore WordPress.WP.CronInterval.CronSchedulesInterval
	add_filter( 'cron_schedules', 'omnisend_cron_schedules' );

	Omnisend_Logs::init();
}

add_action( 'init', 'omnisend_init_crons' );

function omnisend_activated() {
	Omnisend_Logger::enable_logging();

	if ( Omnisend_Helper::is_woocommerce_plugin_activated() ) {
		if ( Omnisend_Helper::check_wp_wc_compatibility() ) {
			Omnisend_Plugin_Event::plugin_activated();
		} else {
			Omnisend_Plugin_Event::failed_plugin_activation( 'Unsupported WordPress version' );
		}
	} else {
		Omnisend_Plugin_Event::failed_plugin_activation( 'WooCommerce not installed or disabled' );
	}
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'add_plugin_settings_link' );
function add_plugin_settings_link( $links ) {
	$link = '<a href="' . admin_url( 'admin.php?page=' . OMNISEND_SETTINGS_PAGE ) . '">' . __( 'Settings' ) . '</a>';
	array_unshift( $links, $link );

	return $links;
}

add_action( 'admin_notices', 'show_connection_notice' );
function show_connection_notice() {
	if ( ! Omnisend_Manager::is_setup() ) {
		?>
		<div class="notice notice-warning is-dismissible omnisend-connection-notice-hidden">
			<p>Connect your <strong>Omnisend account</strong> to boost your sales using Email &amp; SMS.
				<a id="get-started-link"
					href="<?php echo esc_url( admin_url( 'admin.php?page=' . OMNISEND_SETTINGS_PAGE ) ); ?>">Get started
				</a>.
			</p>
			<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span>
			</button>
		</div>
		<?php
	}
}

add_action( 'admin_notices', 'show_api_access_notice' );
function show_api_access_notice() {
	if ( Omnisend_Manager::is_setup() && ! Omnisend_Helper::is_woocommerce_api_access_granted() ) {
		$omnisend_account_id = get_option( 'omnisend_account_id', null );
		$full_url            = Omnisend_Helper::get_wc_auth_url( $omnisend_account_id );

		?>
		<div class="notice notice-error is-dismissible omnisend-connection-notice-hidden">
			<p>
				Add missing permissions to keep Omnisend working with WooCommerce.
				<a id="wp-admin-auth-notice-link"
					data-auth-url="<?php echo esc_url( $full_url ); ?>"
					href="">Add permissions
				</a>
			</p>
		</div>
		<?php

		Omnisend_Plugin_Event::connection_event( Omnisend_Plugin_Event::UPDATE_PERMISSIONS_WP_ADMIN_NOTICE_SHOWN );
	}
}

register_activation_hook( __FILE__, 'omnisend_activate' );
function omnisend_activate() {
	if ( ! current_user_can( 'activate_plugins' ) ) {
		return;
	}

	Omnisend_Install::notify_about_plugin_activation();
}

register_deactivation_hook( __FILE__, 'omnisend_deactivate' );
function omnisend_deactivate() {
	if ( ! current_user_can( 'activate_plugins' ) ) {
		return;
	}

	Omnisend_Install::delete_omnisend_webhooks();
}

register_uninstall_hook( __FILE__, 'omnisend_uninstall' );
function omnisend_uninstall() {
	global $wpdb;
	$table_name = $wpdb->prefix . 'omnisend_logs';
	$sql        = "IF EXISTS(SELECT * FROM   $table_name) DROP TABLE $table_name";
	include_once ABSPATH . 'wp-admin/includes/upgrade.php';
	dbDelta( $sql );

	Omnisend_Install::revoke_omnisend_woo_api_keys();

	$plugin_options = $wpdb->get_results( "SELECT option_name FROM $wpdb->options WHERE option_name LIKE 'omnisend_%'" );

	foreach ( $plugin_options as $option ) {
		delete_option( $option->option_name );
	}

	delete_metadata( 'user', '0', 'omnisend_last_sync', '', true );
	delete_metadata( 'post', '0', 'omnisend_last_sync', '', true );
	delete_metadata( 'term', '0', 'omnisend_last_sync', '', true );
}
